from django.apps import AppConfig
from django.utils.module_loading import autodiscover_modules


class FilePickerConfig(AppConfig):
    name = 'file_picker'

    def ready(self):
        """
        Autodiscover file_pickers modules in other apps.
        """
        autodiscover_modules('file_pickers')



from django.test.runner import DiscoverRunner


class NoChecksRunner(DiscoverRunner):
    # Django 1.11 runs checks before running tests, which causes our urls.py to be loaded before we
    # register our file pickers. This turns that functionality off.

    def run_checks(self):
        pass



import os
import datetime
import json
from tempfile import NamedTemporaryFile

from django.db import models
from django.core.files import File
from django.core.urlresolvers import reverse
from django.test import TestCase
from django.utils.text import capfirst

import file_picker


class Image(models.Model):
    """
    Image Model for tests.
    """
    name = models.CharField(max_length=255)
    description_1 = models.TextField(blank=True)
    description_2 = models.TextField(blank=True)
    file = models.ImageField(upload_to='images/')


class MockRequest(object):
    """
    Incomplete Mock Request object.
    """
    GET = {}
    POST = {}
    FILES = {}


class MockImagePicker(file_picker.ImagePickerBase):
    def __init__(self, name, model, columns, extra_headers, extra={}):
        if columns:
            self.columns = columns
        if extra_headers:
            self.extra_headers = extra_headers
        for key, value in extra.items():
            setattr(self, key, value)
        super(MockImagePicker, self).__init__(name, model)


class BasePickerTest(TestCase):
    """
    Base class to build the
    """
    def setUp(self):
        self.path = os.path.abspath('%s' % os.path.dirname(__file__))
        self.image_file = File(open(os.path.join(self.path, 'static/img/attach.png'), 'rb'), "test_file.png")
        self.image = Image(
            name='Test Image',
            description_1='test desc 1',
            description_2='test desc 2',
            file=self.image_file,
        )
        self.image.save()
        self.request = MockRequest()


class TestListPage(BasePickerTest):
    """
    Test listing page.
    """
    def setUp(self):
        super(TestListPage, self).setUp()
        self.field_names = [f.name for f in Image._meta.get_fields()]
        self.field_names.remove('file')

    def test_all_fields(self):
        """
        Test neither columns nor extra_headers defined.
        """
        image_picker = MockImagePicker('image_test', Image, None, None)
        response = image_picker.list(self.request)
        list_resp = json.loads(response.content.decode('utf-8'))
        self.assertEqual(response.status_code, 200)
        self.assertEqual(self.field_names, list_resp['columns'])
        self.assertEqual([capfirst(Image._meta.get_field(i).verbose_name)
                          for i in self.field_names], list_resp['extra_headers'])

    def test_columns(self):
        """
        Test only columns defined.
        """
        columns = ['description_2', 'name']
        image_picker = MockImagePicker('image_test', Image, columns, None)
        response = image_picker.list(self.request)
        list_resp = json.loads(response.content.decode('utf-8'))
        self.assertEqual(response.status_code, 200)
        self.assertEqual(columns, list_resp['columns'])
        extra_headers = [capfirst(Image._meta.get_field(i).verbose_name)
                         for i in columns]
        self.assertEqual(extra_headers, list_resp['extra_headers'])

    def test_extra_headers(self):
        """
        Test only extra headers defined.  Should ignore it completely.
        """
        image_picker = MockImagePicker('image_test', Image, None, ['Header'])
        response = image_picker.list(self.request)
        list_resp = json.loads(response.content.decode('utf-8'))
        self.assertEqual(response.status_code, 200)
        self.assertEqual(self.field_names, list_resp['columns'])
        self.assertEqual([capfirst(Image._meta.get_field(i).verbose_name)
                          for i in self.field_names], list_resp['extra_headers'])

    def test_columns_and_headers(self):
        """
        Test custom columns and extra headers.
        """
        columns = ['description_2', 'name', 'description_1']
        extra_headers = ['Top Description', 'Image Name', 'Bottom Description']
        image_picker = MockImagePicker('image_test', Image, columns, extra_headers)
        response = image_picker.list(self.request)
        list_resp = json.loads(response.content.decode('utf-8'))
        self.assertEqual(response.status_code, 200)
        self.assertEqual(columns, list_resp['columns'])
        self.assertEqual(extra_headers, list_resp['extra_headers'])

    def test_file_list(self):
        """
        Make sure that the file list gives the correct url.
        """
        image_picker = MockImagePicker('image_test', Image, None, None)
        response = image_picker.list(self.request)
        list_resp = json.loads(response.content.decode('utf-8'))
        results = list_resp['result']
        self.assertEqual(len(results), 1)
        result = results[0]
        self.assertEqual(result['url'], self.image.file.url)

    def test_extra_links(self):
        """
        Test having multiple links works.
        """
        extra = {
            'link_headers': ['URL', 'URL Caps'],
            }
        link_content = ['Click to insert', 'Click to insert Cap']

        class CustomPicker(MockImagePicker):
            def append(self, obj):
                extra = {}
                for name in self.columns:
                    value = getattr(obj, name)
                    if isinstance(value, (datetime.datetime, datetime.date)):
                        value = value.strftime('%b %d, %Y')
                    else:
                        value = str(value)
                    extra[name] = value
                return {
                    'name': str(obj),
                    'url': getattr(obj, self.field).url,
                    'extra': extra,
                    'insert': [getattr(obj, self.field).url,
                               getattr(obj, self.field).url.upper()],
                    'link_content': link_content,
                }
        image_picker = CustomPicker('image_test', Image, None, None, extra=extra)
        response = image_picker.list(self.request)
        self.assertEqual(response.status_code, 200)
        resp = json.loads(response.content.decode('utf-8'))
        self.assertEqual(resp['link_headers'], extra['link_headers'])
        self.assertEqual(resp['link_headers'], extra['link_headers'])
        result = resp['result']
        self.assertEqual(len(result), 1)
        self.assertEqual(result[0]['insert'][0].upper(), result[0]['insert'][1])
        self.assertEqual(result[0]['link_content'], link_content)

    def test_search_page(self):
        """
        Make sure that the search is checking text fields and finding the
        correct results.
        """
        for i in range(0, 3):
            image = Image(
                name='no find %s' % i,
                description_1='desc 1 %s' % i,
                description_2='desc 2 %s' % i,
                file=self.image_file,
            )
            image.save()
        image_picker = MockImagePicker('image_test', Image, None, None)
        qs = image_picker.get_queryset('Test')
        images = qs.all()
        self.assertEqual(images.count(), 1)
        self.assertTrue(self.image in images)
        self.assertFalse(image in images)


class TestUploadPage(TestCase):
    """
    Test the upload
    """
    def setUp(self):
        self.request = MockRequest()
        cwd = os.path.dirname(__file__)
        self.image_picker = MockImagePicker('image_test', Image, None, None)
        self.image_file = File(open(os.path.join(cwd, 'static/img/attach.png'), 'rb'), "test_file.png")

    def test_upload_form_page(self):
        """
        Test form generation.
        """
        response = self.image_picker.upload_file(self.request)
        resp = json.loads(response.content.decode('utf-8'))
        self.assertEqual(response.status_code, 200)
        self.assertTrue('form' in resp)

    def test_upload(self):
        """
        Test the file upload and post.
        """
        request = self.request
        request.FILES = {'userfile': self.image_file}
        response = self.image_picker.upload_file(request)
        self.assertEqual(response.status_code, 200)
        resp = json.loads(response.content.decode('utf-8'))
        self.assertTrue('name' in resp)
        tmp_file = resp['name']
        request.FILES = {}
        request.POST = {
            'name': 'Test Image',
            'description_1': 'description',
            'file': tmp_file,
            }
        response = self.image_picker.upload_file(request)
        resp = json.loads(response.content.decode('utf-8'))
        url = resp['url']
        images = Image.objects.all()
        self.assertEqual(images.count(), 1)
        image = images[0]
        self.assertEqual(url, image.file.url)


class TestPickerSites(TestCase):
    """
    Test the site/registration aspect of file picker.
    """
    def setUp(self):
        self.picker_name = 'test-images'
        file_picker.site.register(Image, file_picker.ImagePickerBase, name=self.picker_name,)
        self.url = reverse('filepicker:index')

    def test_site_index(self):
        response = self.client.get(self.url, {'pickers': [self.picker_name]})
        resp = json.loads(response.content.decode('utf-8'))
        for key, value in resp['pickers'].items():
            self.assertEqual(key, self.picker_name)
            self.assertEqual(value, '/file-picker/%s/' % self.picker_name)

    def test_images_urls(self):
        url = reverse('filepicker:%s:init' % self.picker_name)
        response = self.client.get(url)
        data = json.loads(response.content.decode('utf-8'))
        urls = [list(u.values())[0] for u in list(data['urls'].values())]
        for url in urls:
            response = self.client.get(url)
            self.assertEqual(response.status_code, 200)


class FilePickerUploadFormTests(TestCase):
    def setUp(self):
        self.upload_file = NamedTemporaryFile()
        filename = self.upload_file.name
        self.basename = os.path.basename(filename)
        self.data = {
            'name': 'Pretty Name for this File',
            'file': filename,
        }

    def test_image_form(self):
        form = file_picker.uploads.file_pickers.ImageForm(data=self.data)
        self.assertTrue(form.is_valid(), form.errors)
        instance = form.save()
        # Assert that the file gets placed into the upload_to for this model
        upload_to = 'uploads/images'
        self.assertEqual('{}/{}'.format(upload_to, self.basename), instance.file.name)

    def test_file_form(self):
        form = file_picker.uploads.file_pickers.FileForm(data=self.data)
        self.assertTrue(form.is_valid(), form.errors)
        instance = form.save()
        # Assert that the file gets placed into the upload_to for this model
        upload_to = 'uploads/files'
        self.assertEqual('{}/{}'.format(upload_to, self.basename), instance.file.name)



import os

from django.db import models
from django.conf import settings
from django.utils import timezone
from django.utils.encoding import python_2_unicode_compatible


@python_2_unicode_compatible
class BaseFileModel(models.Model):
    """ Base file model with meta fields """

    name = models.CharField(max_length=255)
    description = models.TextField(blank=True)
    file_size = models.PositiveIntegerField(null=True, blank=True)
    file_type = models.CharField(max_length=16, blank=True)
    date_created = models.DateTimeField()
    date_modified = models.DateTimeField()
    created_by = models.ForeignKey(settings.AUTH_USER_MODEL, related_name="%(app_label)s_%(class)s_created",
                                   null=True, blank=True, on_delete=models.CASCADE)
    modified_by = models.ForeignKey(settings.AUTH_USER_MODEL, related_name="%(app_label)s_%(class)s_modified",
                                    null=True, blank=True, on_delete=models.CASCADE)

    class Meta:
        abstract = True
        ordering = ('-date_modified',)

    def save(self, **kwargs):
        # dates
        now = timezone.now()
        if not self.pk:
            self.date_created = now
        self.date_modified = now
        # file info
        try:
            self.file_size = self.file.size
        except OSError:
            pass
        path, ext = os.path.splitext(self.file.name)
        self.file_type = ext.lstrip('.').upper()
        return super(BaseFileModel, self).save(**kwargs)

    def __str__(self):
        return self.name


class File(BaseFileModel):
    """ Basic file field model """
    file = models.FileField(upload_to='uploads/files/')


class Image(BaseFileModel):
    """ Basic image field model """
    file = models.ImageField(upload_to='uploads/images/')



import os

from django import forms
from django.core.files.base import ContentFile

import file_picker
from file_picker.uploads.models import File, Image


class ImageForm(forms.ModelForm):
    file = forms.CharField(widget=forms.widgets.HiddenInput())

    class Meta(object):
        model = Image
        fields = ('name', 'description')

    def save(self, commit=True):
        image = super(ImageForm, self).save(commit=False)
        # Strip any directory names from the filename
        file_path = os.path.basename(self.cleaned_data['file'])
        fh = ContentFile(open(self.cleaned_data['file'], 'rb').read())
        image.file.save(file_path, fh)
        if commit:
            image.save()
        return image


class FileForm(forms.ModelForm):
    file = forms.CharField(widget=forms.widgets.HiddenInput())

    class Meta(object):
        model = File
        fields = ('name', 'description')

    def save(self, commit=True):
        image = super(FileForm, self).save(commit=False)
        # Strip any directory names from the filename
        file_path = os.path.basename(self.cleaned_data['file'])
        fh = ContentFile(open(self.cleaned_data['file'], 'rb').read())
        image.file.save(file_path, fh)
        if commit:
            image.save()
        return image


class ImagePicker(file_picker.ImagePickerBase):
    form = ImageForm
    columns = ('name', 'file_type', 'date_modified')
    extra_headers = ('Name', 'File Type', 'Date Modified')


class FilePicker(file_picker.FilePickerBase):
    form = FileForm
    columns = ('name', 'file_type', 'date_modified')
    extra_headers = ('Name', 'File type', 'Date modified')


file_picker.site.register(Image, ImagePicker, name='images')
file_picker.site.register(File, FilePicker, name='files')



import json

from django.conf.urls import url
from django.core.urlresolvers import reverse, NoReverseMatch
from django.db import models
from django.db.models.base import ModelBase, FieldDoesNotExist
from django.http import HttpResponse

import file_picker


class FilePickerSite(object):

    def __init__(self, name=None, app_name='file-picker'):
        self._registry = []

    def guess_default(self, model):
        for field_name in model._meta.get_all_field_names():
            try:
                field = model._meta.get_field(field_name)
            except FieldDoesNotExist:
                continue
            if isinstance(field, models.ImageField):
                return file_picker.ImagePickerBase
            elif isinstance(field, models.FileField):
                return file_picker.FilePickerBase
        return file_picker.FilePickerBase

    def register(self, model_or_iterable, class_=None, name=None, **options):
        if isinstance(model_or_iterable, ModelBase):
            model_or_iterable = [model_or_iterable]
        for model in model_or_iterable:
            if not name:
                view_name = class_.__class__.__name__.lower()
                model_name = model().__class__.__name__.lower()
                name = "%s-%s" % (model_name, view_name)
            if class_:
                picker_class = class_
            else:
                picker_class = self.guess_default(model)
            self._registry.append({'name': name, 'picker': picker_class(name, model)})

    def get_urls(self):
        urlpatterns = [
            url(r'^$', self.primary, name='index'),
        ]
        for p in self._registry:
            urlpatterns += url(r'^%s/' % p['name'], p['picker'].urls),
        return (urlpatterns, None, "filepicker")
    urls = property(get_urls)

    def primary(self, request):
        picker_names = request.GET.getlist('pickers')
        pickers = {}
        for name in picker_names:
            try:
                pickers[name] = reverse('filepicker:%s:init' % name)
            except NoReverseMatch:
                pickers[name] = None
        data = {'pickers': pickers}
        return HttpResponse(json.dumps(data), content_type='application/json')


site = FilePickerSite()



import datetime
import json
import logging
import os
import tempfile
import traceback

from django.conf.urls import url
from django.core.paginator import Paginator, EmptyPage
from django.core.urlresolvers import reverse
from django.db import models
from django.db.models import Q
from django.http import HttpResponse, HttpResponseServerError
from django.utils.text import capfirst

from sorl.thumbnail.helpers import ThumbnailError
from sorl.thumbnail import get_thumbnail

from file_picker.forms import QueryForm, model_to_AjaxItemForm


logger = logging.getLogger(__name__)


class FilePickerBase(object):
    model = None
    form = None
    page_size = 4
    link_headers = ['Insert File', ]
    extra_headers = None
    columns = None
    ordering = None

    def __init__(self, name, model):
        self.name = name
        self.model = model
        if not self.form:
            self.form = model_to_AjaxItemForm(self.model)
        self.field_names = [f.name for f in model._meta.get_fields()]
        build_headers = not self.columns or not self.extra_headers
        if not self.columns:
            self.columns = self.field_names
        extra_headers = []
        for field_name in self.field_names:
            try:
                field = model._meta.get_field(field_name)
            except models.FieldDoesNotExist:
                self.field_names.remove(field_name)
                continue
            if isinstance(field, (models.ImageField, models.FileField)):
                self.field = field_name
                self.field_names.remove(field_name)
            elif isinstance(field, (models.ForeignKey, models.ManyToManyField)):
                self.field_names.remove(field_name)
        for field_name in self.columns:
            try:
                field = model._meta.get_field(field_name)
            except models.FieldDoesNotExist:
                self.field_names.remove(field_name)
                continue
            extra_headers.append(capfirst(field.verbose_name))
        if build_headers:
            self.extra_headers = extra_headers

    def protect(self, view, csrf_exempt=False):
        def wrapper(*args, **kwargs):
            data = {}
            try:
                return view(*args, **kwargs)
            except Exception as e:
                logger.exception("error in view")
                data['errors'] = [traceback.format_exc(e)]
            return HttpResponse(json.dumps(data), content_type='application/json')
        wrapper.csrf_exempt = csrf_exempt
        return wrapper

    def get_urls(self):
        urlpatterns = [
            url(r'^$', self.setup, name='init'),
            url(r'^files/$', self.list, name='list-files'),
            url(r'^upload/file/$', self.protect(self.upload_file, True),
                name='upload-file'),
        ]
        return (urlpatterns, None, self.name)
    urls = property(get_urls)

    def setup(self, request):
        data = {}
        data['urls'] = {
            'browse': {'files': reverse('filepicker:%s:list-files' % self.name)},
            'upload': {'file': reverse('filepicker:%s:upload-file' % self.name)},
        }
        return HttpResponse(json.dumps(data), content_type='application/json')

    def append(self, obj):
        extra = {}
        for name in self.columns:
            value = getattr(obj, name)
            if isinstance(value, (datetime.datetime, datetime.date)):
                value = value.strftime('%b %d, %Y')
            else:
                value = str(value)
            extra[name] = value
        return {
            'name': str(obj),
            'url': getattr(obj, self.field).url,
            'extra': extra,
            'insert': [getattr(obj, self.field).url, ],
            'link_content': ['Click to insert'],
        }

    def get_queryset(self, search):
        qs = Q()
        if search:
            for name in self.field_names:
                comparision = {}
                comparision[name] = search
                qs = qs | Q(name__contains=search)
            queryset = self.model.objects.filter(qs)
        else:
            queryset = self.model.objects.all()
        if self.ordering:
            queryset = queryset.order_by(self.ordering)
        else:
            # Need to default to some kind of ordering since we paginate
            queryset = queryset.order_by('-pk')
        return queryset

    def upload_file(self, request):
        if 'userfile' in request.FILES:
            name, ext = os.path.splitext(request.FILES['userfile'].name)
            fn = tempfile.NamedTemporaryFile(prefix=name, suffix=ext, delete=False)
            f = request.FILES['userfile']
            for chunk in f.chunks():
                fn.write(chunk)
            fn.close()
            return HttpResponse(json.dumps({'name': fn.name}), content_type='application/json')
        else:
            form = self.form(request.POST or None)
            if form.is_valid():
                obj = form.save()
                data = self.append(obj)
                return HttpResponse(json.dumps(data),
                                    content_type='application/json')
            data = {'form': form.as_table()}
            return HttpResponse(json.dumps(data), content_type='application/json')

    def list(self, request):
        form = QueryForm(request.GET)
        if not form.is_valid():
            return HttpResponseServerError()
        page = form.cleaned_data['page']
        result = []
        qs = self.get_queryset(form.cleaned_data['search'])
        pages = Paginator(qs, self.page_size)
        try:
            page_obj = pages.page(page)
        except EmptyPage:
            return HttpResponseServerError()
        for obj in page_obj.object_list:
            result.append(self.append(obj))
        data = {
            'page': page,
            'pages': list(pages.page_range),
            'search': form.cleaned_data['search'],
            'result': result,
            'has_next': page_obj.has_next(),
            'has_previous': page_obj.has_previous(),
            'link_headers': self.link_headers,
            'extra_headers': self.extra_headers,
            'columns': self.columns,
        }
        return HttpResponse(json.dumps(data), content_type='application/json')


class ImagePickerBase(FilePickerBase):
    link_headers = ['Thumbnail', ]

    def append(self, obj):
        json = super(ImagePickerBase, self).append(obj)
        img = '<img src="{0}" alt="{1}" width="{2}" height="{3}" />'
        try:
            thumb = get_thumbnail(obj.file.path, '150x150', crop='center', quality=99)
        except ThumbnailError:
            logger.exception()
            thumb = None
        if thumb:
            json['link_content'] = [img.format(thumb.url, 'image', thumb.width, thumb.height), ]
            json['insert'] = ['<img src="%s" />' % getattr(obj, self.field).url, ]
        else:
            json['link_content'] = [img.format('', 'Not Found', 150, 150), ]
            json['insert'] = [img.format('', 'Not Found', 150, 150), ]
        return json



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
from django.conf import settings


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='File',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('name', models.CharField(max_length=255)),
                ('description', models.TextField(blank=True)),
                ('file_size', models.PositiveIntegerField(null=True, blank=True)),
                ('file_type', models.CharField(max_length=16, blank=True)),
                ('date_created', models.DateTimeField()),
                ('date_modified', models.DateTimeField()),
                ('file', models.FileField(upload_to=b'uploads/files/')),
                ('created_by', models.ForeignKey(related_name=b'uploads_file_created', blank=True, to=settings.AUTH_USER_MODEL, null=True, on_delete=models.CASCADE)),
                ('modified_by', models.ForeignKey(related_name=b'uploads_file_modified', blank=True, to=settings.AUTH_USER_MODEL, null=True, on_delete=models.CASCADE)),
            ],
            options={
                'ordering': ('-date_modified',),
                'abstract': False,
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Image',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('name', models.CharField(max_length=255)),
                ('description', models.TextField(blank=True)),
                ('file_size', models.PositiveIntegerField(null=True, blank=True)),
                ('file_type', models.CharField(max_length=16, blank=True)),
                ('date_created', models.DateTimeField()),
                ('date_modified', models.DateTimeField()),
                ('file', models.ImageField(upload_to=b'uploads/images/')),
                ('created_by', models.ForeignKey(related_name=b'uploads_image_created', blank=True, to=settings.AUTH_USER_MODEL, null=True, on_delete=models.CASCADE)),
                ('modified_by', models.ForeignKey(related_name=b'uploads_image_modified', blank=True, to=settings.AUTH_USER_MODEL, null=True, on_delete=models.CASCADE)),
            ],
            options={
                'ordering': ('-date_modified',),
                'abstract': False,
            },
            bases=(models.Model,),
        ),
    ]



from django import forms
from django.contrib import admin
from sample_project.article.models import Post


class PostForm(forms.ModelForm):

    def __init__(self, *args, **kwargs):
        super(PostForm, self).__init__(*args, **kwargs)
        from file_picker.widgets import SimpleFilePickerWidget
        from file_picker.wymeditor.widgets import WYMeditorWidget
        pickers = {'image': "images", 'file': "files"}
        # simple widget
        simple_widget = SimpleFilePickerWidget(pickers=pickers)
        self.fields['body'].widget = simple_widget
        # wymeditor widget
        wym_widget = WYMeditorWidget(pickers=pickers)
        self.fields['teaser'].widget = wym_widget

    class Meta(object):
        model = Post
        fields = '__all__'


class PostAdmin(admin.ModelAdmin):

    form = PostForm

    class Media:
        js = ("http://cdn.jquerytools.org/1.2.5/full/jquery.tools.min.js",)


admin.site.register(Post, PostAdmin)



from django import forms


class FilePickerWidget(forms.Textarea):
    """ Base file picker widget that can be extended """

    def __init__(self, pickers, *args, **kwargs):
        self.pickers = pickers
        classes = kwargs.pop('classes', ['filepicker'])
        super(FilePickerWidget, self).__init__(*args, **kwargs)
        if 'file' in pickers:
            classes.append("file_picker_name_file_%s" % pickers['file'])
        if 'image' in pickers:
            classes.append("file_picker_name_image_%s" % pickers['image'])
        self.attrs['class'] = ' '.join(classes)


class SimpleFilePickerWidget(FilePickerWidget):
    """ Basic widget that provides Image/File links """

    def __init__(self, pickers, *args, **kwargs):
        kwargs['classes'] = ['simple-filepicker']
        super(SimpleFilePickerWidget, self).__init__(pickers, *args, **kwargs)

    class Media:
        css = {"all": ("css/filepicker.overlay.css",)}
        js = ("js/ajaxupload.js",
              "js/jquery.filepicker.js",
              "js/jquery.filepicker.simple.js")



import os

from django import forms
from django.core.files.base import ContentFile
from django.db import models
from django.db.models.base import FieldDoesNotExist


class QueryForm(forms.Form):
    page = forms.IntegerField(min_value=0, required=False)
    search = forms.CharField(
        max_length=300, required=False,
    )

    def clean_page(self):
        page = self.cleaned_data.get('page')
        return page or 1


FIELD_EXCLUDES = (models.ImageField, models.FileField)


def model_to_AjaxItemForm(model):
    exclude = []
    for field_name in [f.name for f in model._meta.get_fields()]:
        try:
            field = model._meta.get_field(field_name)
        except FieldDoesNotExist:
            exclude.append(field_name)
            continue
        if isinstance(field, FIELD_EXCLUDES):
            exclude.append(field_name)
    meta = type('Meta', (), {"model": model, "exclude": exclude})
    modelform_class = type('modelform', (AjaxItemForm,), {"Meta": meta})
    return modelform_class


class AjaxItemForm(forms.ModelForm):
    file = forms.CharField(widget=forms.widgets.HiddenInput())

    def clean_file(self):
        file = self.cleaned_data['file']
        if not os.path.exists(file):
            raise forms.ValidationError('Missing file')
        return file

    def save(self, *args, **kwargs):
        item = super(AjaxItemForm, self).save(commit=False)
        # Strip any directory names from the filename
        filename = os.path.basename(self.cleaned_data['file'])
        getattr(item, self.Meta.exclude[0]).save(
            filename,
            ContentFile(open(str(self.cleaned_data['file']), 'rb').read())
        )
        item.save(*args, **kwargs)
        return item



from file_picker.widgets import FilePickerWidget


class WYMeditorWidget(FilePickerWidget):
    def __init__(self, pickers, *args, **kwargs):
        kwargs['classes'] = ['wymeditor']
        super(WYMeditorWidget, self).__init__(pickers, *args, **kwargs)

    class Media:
        css = {"all": ("css/filepicker.overlay.css",)}
        js = ("js/ajaxupload.js",
              "js/jquery.filepicker.js",
              "wymeditor/jquery.wymeditor.js",
              "js/jquery.wymeditor.filepicker.js")



from django.conf.urls import url
from django.contrib import admin
from django.conf import settings
from django.views.static import serve

import file_picker

urlpatterns = [
    url(r'^admin/', admin.site.urls),
    url(r'^file-picker/', file_picker.site.urls),

    url(r'^%s(?P<path>.*)' % settings.MEDIA_URL.lstrip('/'),
        serve,
        {'document_root': settings.MEDIA_ROOT, 'show_indexes': True})
]



from setuptools import setup, find_packages

setup(
    name='django-file-picker',
    version='0.9.1',
    author='Caktus Consulting Group',
    author_email='solutions@caktusgroup.com',
    packages=find_packages(exclude=['sample_project']),
    include_package_data=True,
    url='https://github.com/caktus/django-file-picker/',
    license='BSD',
    description='Pluggable file picker',
    classifiers=[
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Development Status :: 5 - Production/Stable',
        'Operating System :: OS Independent',
    ],
    long_description=open('README.rst').read(),
    install_requires=[
        'sorl-thumbnail>=12.4a1',
        'Pillow>=3.1.0,<4.0',
    ],
    zip_safe=False,  # because we're including media that Django needs
)



# Aliases allow users to import directly from file_picker.*
from file_picker.views import FilePickerBase, ImagePickerBase  # noqa
from file_picker.sites import site, FilePickerSite  # noqa
from file_picker import widgets  # noqa

VERSION = (0, 9, 1,)
__version__ = '.'.join(map(str, VERSION))
default_app_config = 'file_picker.apps.FilePickerConfig'
